TuLiP User's Guide
==================

Welcome to TuLiP, the Temporal Logic Planning Toolbox.  This user's guide is
intended for people who are interested in making use of TuLiP to synthesize
reactive controllers for hybrid systems and perform related functions.

Contents:

.. toctree::
   :numbered:
   :maxdepth: 2

   intro
   install
   tutorial
   specifications
   transys
   codegen
   gridworlds
   benchmarks
   formulations
   dev_guide
   bibliography

Special pages:

* :ref:`genindex`
* :ref:`search`
